<?php
// Simulate database data
$shops = [
    1 => [
        'name' => 'Prime Shop',
        'location' => 'Downtown',
        'price' => '₦200,000/month',
        'description' => 'Spacious shop in a prime location. Perfect for any business.',
        'images' => [
            'https://via.placeholder.com/600x400?text=Prime+Shop+1',
            'https://via.placeholder.com/600x400?text=Prime+Shop+2',
            'https://via.placeholder.com/600x400?text=Prime+Shop+3',
        ],
    ],
    2 => [
        'name' => 'Cozy Corner',
        'location' => 'Suburb',
        'price' => '₦100,000/month',
        'description' => 'Affordable shop with great foot traffic.',
        'images' => [
            'https://via.placeholder.com/600x400?text=Cozy+Corner+1',
            'https://via.placeholder.com/600x400?text=Cozy+Corner+2',
        ],
    ],
    3 => [
        'name' => 'Elite Plaza',
        'location' => 'City Center',
        'price' => '₦300,000/month',
        'description' => 'High-end shop space for premium businesses.',
        'images' => [
            'https://via.placeholder.com/600x400?text=Elite+Plaza+1',
            'https://via.placeholder.com/600x400?text=Elite+Plaza+2',
        ],
    ],
];

// Get shop ID from query parameter
$id = isset($_GET['id']) ? (int) $_GET['id'] : 0;

if (!isset($shops[$id])) {
    die('Shop not found.');
}

$shop = $shops[$id];
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $shop['name']; ?> Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #eaf6ff;
            font-family: Arial, sans-serif;
        }
        header {
            background: linear-gradient(90deg, #007bff, #0056b3);
            color: white;
            padding: 40px 0;
            text-align: center;
        }
        header h1 {
            font-size: 2.5rem;
            margin-bottom: 10px;
        }
        header p {
            font-size: 1.2rem;
        }
        .details-card {
            animation: fadeIn 1s ease-in-out;
            background: #ffffff;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
            border-radius: 10px;
            overflow: hidden;
        }
        .carousel img {
            height: 300px;
            object-fit: cover;
        }
        @keyframes fadeIn {
            from {
                opacity: 0;
                transform: translateY(20px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }
        .btn-primary {
            background-color: #007bff;
            border: none;
        }
        .btn-primary:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header>
        <h1><?php echo $shop['name']; ?></h1>
        <p>Discover the details and images of this amazing shop</p>
    </header>

    <!-- Shop Details -->
    <div class="container py-5">
        <div class="row">
            <!-- Image Carousel -->
            <div class="col-md-6">
                <div id="shopCarousel" class="carousel slide details-card" data-bs-ride="carousel">
                    <div class="carousel-inner">
                        <?php
                        $active = 'active';
                        foreach ($shop['images'] as $image) {
                            echo "
                            <div class='carousel-item $active'>
                                <img src='$image' class='d-block w-100' alt='Shop Image'>
                            </div>";
                            $active = ''; // Only the first image should have the "active" class
                        }
                        ?>
                    </div>
                    <button class="carousel-control-prev" type="button" data-bs-target="#shopCarousel" data-bs-slide="prev">
                        <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                        <span class="visually-hidden">Previous</span>
                    </button>
                    <button class="carousel-control-next" type="button" data-bs-target="#shopCarousel" data-bs-slide="next">
                        <span class="carousel-control-next-icon" aria-hidden="true"></span>
                        <span class="visually-hidden">Next</span>
                    </button>
                </div>
            </div>

            <!-- Shop Info -->
            <div class="col-md-6">
                <div class="details-card p-4">
                    <h3><?php echo $shop['name']; ?></h3>
                    <p><strong>Location:</strong> <?php echo $shop['location']; ?></p>
                    <p><strong>Price:</strong> <?php echo $shop['price']; ?></p>
                    <p><?php echo $shop['description']; ?></p>
                    <a href="index.php" class="btn btn-primary mt-3">Back to Shops</a>
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap Bundle with Popper -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
